@@ -1,10 +1,33 @@
 #' @import checkmate
-#' @importFrom data.table data.table := set fread fwrite rbindlist setnames
+#' @import cli
+#' @import data.table
 #' @importFrom glue glue
 #' @importFrom httr GET POST content add_headers headers cookies set_cookies
 NULL
 
 
+assert_form_ids = function(auth, form_ids) {
+  assert_character(
+    form_ids, any.missing = FALSE, min.len = 1L, unique = TRUE, null.ok = TRUE)
+  if (!is.null(form_ids)) return(form_ids)
+  catalog = scto_catalog(auth)
+  ids = catalog[catalog$type == 'form']$id
+  ids
+}
+
+
+get_api_response = function(auth, request_url) {
+  res = GET(request_url, add_headers('x-csrf-token' = auth$csrf_token))
+  status = res$status_code
+  content = rawToChar(res$content)
+  if (status != 200L) {
+    cli_alert_warning('Response content:\n{content}')
+    scto_abort('Non-200 response: {status}')
+  }
+  content
+}
+
+
 #' Suppress or permit messages from rsurveycto
 #'
 #' By default, rsurveycto prints messages to the console. To suppress them, set
@@ -32,13 +55,15 @@ scto_quiet = function(quiet = NULL) {
 
 
 scto_theme = function() {
+  common = list(before = '"', after = '"')
   # Okabe-Ito colors
   list(
-    span.server = list(color = '#E69F00'), # orange
-    span.id = list(color = '#D55E00'), # vermillion
-    span.dataset = list(color = '#56B4E9'), # skyblue
-    span.form = list(color = '#009E73'), # bluishgreen
-    span.filename = list(color = '#CC79A7')) # reddishpurple
+    span.server = c(color = '#E69F00', common), # orange
+    span.id = c(color = '#D55E00', common), # vermillion
+    span.dataset = c(color = '#56B4E9', common), # skyblue
+    span.form = c(color = '#009E73', common), # bluishgreen
+    span.version = c(color = '#F5C710', common), # amber
+    span.filename = c(color = '#CC79A7', common)) # reddishpurple
 }
 
 
@@ -46,16 +71,15 @@ scto_bullets = function(text, .envir = parent.frame()) {
   if (isTRUE(scto_quiet()) || identical(Sys.getenv('TESTTHAT'), 'true')) {
     return(invisible())
   }
-
-  cli::cli_div(theme = scto_theme())
-  cli::cli_bullets(text, .envir = .envir)
+  cli_div(theme = scto_theme())
+  cli_bullets(text, .envir = .envir)
 }
 
 
 scto_abort = function(message, ..., .envir = parent.frame()) {
   call = rlang::caller_env()
-  cli::cli_div(theme = scto_theme())
-  cli::cli_abort(message = message, ..., .envir = .envir, call = call)
+  cli_div(theme = scto_theme())
+  cli_abort(message = message, ..., .envir = .envir, call = call)
 }
 
 
@@ -79,8 +103,6 @@ is_empty = function(x) {
 #' d = data.table(w = 3:4, x = c('', 'foo'), y = c(NA, NA), z = c(NA, ''))
 #' drop_empties(d)
 #'
-#' @seealso [scto_write()]
-#'
 #' @export
 drop_empties = function(d) {
   assert_data_table(d)
